==> qutewindow-0.1.20-py3-none-any.whl: qutewindow/platforms/windows/QuteDialog.py <==
from typing import Optional

from PySide6.QtCore import Qt, QByteArray
from PySide6.QtGui import QShowEvent
from PySide6.QtWidgets import QWidget, QDialog

from qutewindow.platforms.windows.native_event import _nativeEvent
from qutewindow.platforms.windows.title_bar.TitleBar import TitleBar
from qutewindow.platforms.windows.utils import addShadowEffect, addWindowAnimation, setWindowNonResizable, \
    isWindowResizable


class QuteDialog(QDialog):
    def __init__(self, parent: Optional[QWidget] = None) -> None:
        super().__init__(parent)
        self.setWindowFlags(Qt.WindowType.Window | Qt.FramelessWindowHint)

        addShadowEffect(self.winId())
        addWindowAnimation(self.winId())

        self.title_bar = TitleBar(self)

        self.resize(800, 800)

    def setNonResizable(self):
        setWindowNonResizable(self.winId())
        self.title_bar.maximize_button.hide()

    def isResizable(self) -> None:
        return isWindowResizable(self.winId())

    def showEvent(self, event: QShowEvent) -> None:
        self.title_bar.raise_()
        super(QuteDialog, self).showEvent(event)

    def nativeEvent(self, event_type: QByteArray, message: int):
        ret_tuple = _nativeEvent(self, event_type, message)
        if ret_tuple is not None:
            ret, value = ret_tuple
            if ret:
                return ret, value
        super().nativeEvent(event_type, message)

    def resizeEvent(self, e):
        super().resizeEvent(e)
        if hasattr(self, "title_bar"):
            self.title_bar.resize(self.width(), self.title_bar.height())

==> qutewindow-0.1.25-py3-none-any.whl: qutewindow/platforms/windows/QuteDialog.py <==
from typing import Optional

from PySide6.QtCore import Qt, QByteArray
from PySide6.QtGui import QShowEvent
from PySide6.QtWidgets import QWidget, QDialog

from qutewindow.platforms.windows.native_event import _nativeEvent
from qutewindow.platforms.windows.title_bar.TitleBar import TitleBar
from qutewindow.platforms.windows.utils import addShadowEffect, addWindowAnimation, setWindowNonResizable, \
    isWindowResizable


class QuteDialog(QDialog):
    def __init__(self, parent: Optional[QWidget] = None) -> None:
        super().__init__(parent)
        self._title_bar = TitleBar(self)

        self.createWinId()

        addShadowEffect(self.winId())
        addWindowAnimation(self.winId())

        self.resize(800, 800)

    def titleBar(self) -> QWidget:
        return self._title_bar

    def setTitleBar(self, titleBar: QWidget) -> None:
        self._title_bar = titleBar
        self.update()

    def setNonResizable(self):
        setWindowNonResizable(self.winId())
        self._title_bar.maximize_button.hide()

    def isResizable(self) -> None:
        return isWindowResizable(self.winId())

    def showEvent(self, event: QShowEvent) -> None:
        self._title_bar.raise_()
        super(QuteDialog, self).showEvent(event)

    def nativeEvent(self, event_type: QByteArray, message: int):
        return _nativeEvent(self, event_type, message)

    def resizeEvent(self, e):
        super().resizeEvent(e)
        self._title_bar.resize(self.width(), self._title_bar.height())
